@@ -1,7 +1,7 @@
 package CPANPLUS::YACSmoke;
-$CPANPLUS::YACSmoke::VERSION = '1.03_03'; # TRIAL
+$CPANPLUS::YACSmoke::VERSION = '1.03_04'; # TRIAL
 
-$CPANPLUS::YACSmoke::VERSION = '1.0303';# Dist::Zilla: +PodWeaver
+$CPANPLUS::YACSmoke::VERSION = '1.0304';# Dist::Zilla: +PodWeaver
 #ABSTRACT: Yet Another CPANPLUS Smoke Tester
 
 use strict;
@@ -165,6 +165,7 @@ sub test {
      $self->_setup_local_lib();
      $self->{conf}->_perl5lib( $ENV{PERL5LIB} );
      $target = 'install';
+     msg("Setup local::lib environment in '$ENV{PERL_LOCAL_LIB_ROOT}'");
   }
 
   foreach my $mod ( @mods ) {
@@ -179,7 +180,15 @@ sub test {
      };
   }
 
-  $self->{cpanplus}->save_state();
+  if ( $self->{local_lib} ) {
+    my $build_dir = $self->_get_build_dir();
+    msg("Flushing '$build_dir'");
+    rmtree($build_dir) if -e $build_dir;
+    msg("Flushed '$build_dir'");
+  }
+
+  $self->{cpanplus}->save_state() if !$self->{local_lib};
+
   return 1;
 }
 
@@ -474,7 +483,7 @@ CPANPLUS::YACSmoke - Yet Another CPANPLUS Smoke Tester
 
 =head1 VERSION
 
-version 1.03_03
+version 1.03_04
 
 =head1 SYNOPSIS
 
